@@ -1,12 +1,12 @@
 package String::Multibyte::Unicode;
 
-require 5.007; # maybe 5.008
+require 5.008;
 use vars qw($VERSION);
-$VERSION = '1.01';
+$VERSION = '1.02';
 
 +{
     charset  => 'Unicode',
-    regexp   => '(?s:.)',
+    regexp   => qr/./s,
     nextchar => sub { pack 'U', 1 + unpack('U', $_[0]) },
     cmpchar  => sub { $_[0] cmp $_[1] },
 };
@@ -16,29 +16,30 @@ __END__
 =head1 NAME
 
 String::Multibyte::Unicode - internally used by String::Multibyte
-for Unicode (Perl internal format)
+for Unicode (Perl's internal format)
 
 =head1 SYNOPSIS
 
     use String::Multibyte;
 
-    $unicode = String::Multibyte->new('Unicode');
+    $uni = String::Multibyte->new('Unicode');
     $unicode_length = $uni->length($unicode_string);
 
 =head1 DESCRIPTION
 
 C<String::Multibyte::Unicode> is used for manipulation of strings
-in Perl internal format for Unicode.
+in Perl's internal format for Unicode.
 
-=head1 BUGS
+=head1 CAVEAT
 
-Surrogates, C<0xD800..0xDFFF>, and other non-characters may be included
+This module requires Perl 5.8.0 or later.
+
+Surrogates, C<U+D800..U+DFFF>, and other non-characters may be included
 in a character range, but may be ignored, warned, or croaked,
-by the C<CORE::> unicode support.
+by the C<CORE::> Unicode support.
 
 =head1 SEE ALSO
 
 L<String::Multibyte>
 
 =cut
-
